HotCandy = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceConsole-2.0", "AceDB-2.0", "CandyBar-2.0")

local HotCandy = HotCandy

local VERSION = tonumber(("$Revision: 42857 $"):match("%d+"))
HotCandy.revision = VERSION
HotCandy.versionstring = "1.0 |cffff8888r%d|r"
HotCandy.version = HotCandy.versionstring:format(VERSION)
HotCandy.date = ("$Date: 2007-07-05 11:45:22 -0400 (Thu, 05 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")

local BS = AceLibrary("Babble-Spell-2.2")
local media = AceLibrary:HasInstance("SharedMedia-1.0") and AceLibrary("SharedMedia-1.0") or { Fetch = function() return "Interface\\Addons\\HotCandy\\textures\\default" end, List = function() return {"BantoBar"} end, Register = function() end, }

local mType = media.MediaType and media.MediaType.STATUSBAR or "statusbar"

function HotCandy:OnInitialize()
	self:RegisterDB("HotCandyDB")
	self:RegisterDefaults("profile", {
		growup = false,
		texture = "BantoBar",
		barwidth = 200,
	})
	
	media:Register(mType, "BantoBar", "Interface\\Addons\\HotCandy\\textures\\default")
	
	self.options = {
		type = "group",
		args = {
			anchor = {
				name = "Show Anchor",
				desc = "Show the Anchor for moving the Bars",
				type = "execute",
				func = "ShowAnchors",
			},
			growup = {
				name = "Grow Up",
				desc = "Toggle Grow Up of the Bars",
				type = "toggle",
				get = function()
					return self.db.profile.growup
				end,
				set = function(v)
					self.db.profile.growup = v
				end,
			},
			texture = {
				type = "text",
				name = "Texture",
				desc = "Set the texture for the bars.",
				validate = media:List(mType),
				get = function() return self.db.profile.texture end,
				set = function(tex) self.db.profile.texture = tex end,
			},
			width = {
				type = "range",
				name = "Bar Width",
				desc = "Set the width of the bars.",
				min = 50, max = 500, step = 1, bigStep = 10,
				get = function() return self.db.profile.barwidth end,
				set = function(width) self.db.profile.barwidth = width end,
			}
		}
	}
	
	self:RegisterChatCommand({ "/hot", "/hotcandy" }, self.options )
	
	self.spell = {}
	
	self.itemSets = {
		["Stormrage"] = { 16897, 16898, 16899, 16900, 16901, 16902, 16903, 16904 },
		["Nordrassil"] = { 30216, 30217, 30219, 30220, 30221 },
		["Transcendence"] = { 16919, 16920, 16921, 16922, 16923, 16924, 16925, 16926 },
	}
	-- spell = duration
	self.durations = {
		['Rejuvenation'] = 12,
		['Regrowth'] = 21,
		['Renew'] = 15,
		['Greater Heal'] = 0,
		['Lifebloom'] = 7,
		['Gift of the Naaru'] = 15,
	}
	self.track = {}
end

function HotCandy:OnEnable()
	self:SetupFrames()
	self:RegisterEvent("UNIT_SPELLCAST_SENT", "SpellCastEvent")
	self:RegisterEvent("UNIT_SPELLCAST_SUCCEEDED", "SpellCastEvent")
  self:RegisterBucketEvent("UNIT_INVENTORY_CHANGED", 0.25, "equipChanged")
	
	self:UpdateSetBonus()
end

function HotCandy:UpdateSetBonus()
	local _, class = UnitClass("player")
	
	for k,v in pairs(self.durations) do
		local key = BS[k]
		if not self.track[key] then
			self.track[key] = { icon = BS:GetSpellIcon(k) }
		end
		self.track[key].duration = v
	end
	
	if class == "DRUID" then
		if (self:getWornSetPieces("Stormrage") >= 8) then
			self.track[BS['Rejuvenation']].duration = self.track[BS['Rejuvenation']].duration + 3
		end
		if (self:getWornSetPieces("Nordrassil") >= 2) then
			self.track[BS['Regrowth']].duration = self.track[BS['Regrowth']].duration + 6
		end
	elseif class == "PRIEST" then
		if (self:getWornSetPieces("Transcendence") >= 8) then
			self.track[BS['Greater Heal']].duration = self.track[BS['Greater Heal']].duration + 15
		end
	end
end

-- taken from Threat-1.0
function HotCandy:getWornSetPieces(name)
	local ct = 0
	local data = self.itemSets[name]
	if data then
		for _, itemID in ipairs(data) do
			if IsEquippedItem( itemID ) then
				ct = ct + 1
			end
		end
	end
	return ct
end

function HotCandy:equipChanged(units)
	if (units and not units.player) or InCombatLockdown() then
		return
	end
	self:UpdateSetBonus()
end

function HotCandy:SpellCastEvent(unit, spell, rank, target)
	if ( event == "UNIT_SPELLCAST_SENT" ) then
		self.spell['spell'] = spell
		self.spell['target'] = target
	elseif ( event == "UNIT_SPELLCAST_SUCCEEDED" ) then
		if self.spell['spell'] == spell then
			self:FireSpell(spell, self.spell['target'])
		end
		self.spell['spell'] = nil
	end
end

function HotCandy:FireSpell(spellName, spellTarget)
	local spell = self.track[spellName]
  if spell and spell.duration > 0 then
		self:ShowCandyBar(spellName .. " - " .. (spellTarget or ""), spell.duration, spell.icon, "green", "yellow", "orange", "red")
	end
end

function HotCandy:ShowCandyBar(text, time, icon, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10)
	local id = "HotCandy"..text
	local u = self.db.profile.growup
	self:RegisterCandyBarGroup("HotCandyGroup")
	self:SetCandyBarGroupPoint("HotCandyGroup", u and "BOTTOM" or "TOP", self.frames.anchor, u and "TOP" or "BOTTOM", 0, 0)
	self:SetCandyBarGroupGrowth("HotCandyGroup", u)
	
	self:RegisterCandyBar(id, time, text, icon, c1, c2, c3, c4, c5, c6, c7, c8, c9, c10)
	self:RegisterCandyBarWithGroup(id, "HotCandyGroup")
	self:SetCandyBarTexture(id, media:Fetch(mType, self.db.profile.texture))
	self:SetCandyBarFade(id, 5)
  self:SetCandyBarWidth(id, self.db.profile.barwidth)
	self:StartCandyBar(id, true)
end
